ReportManager class

Constructors

ReportManager()

Properties

authService → AuthService
no setter
client LittleFishReportClient
final
core ↔ LittleFishCore
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isReady bool
no setter
logger → LoggerService
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings → ReportSettings
no setter

Methods

getUserReportById(String businessId, int id, String reportType) Future<Report>
getUserReports(String businessId) Future<List<Report>>
getUserReportUrl(String businessId, Report item) Future<String>
initialise(ReportSettings settings) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited